<?php

namespace Cms\Article\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Cms\Article\Interfaces\ArticleRepositoryInterface;

class ArticlePublicController extends BaseController
{
    // use ArticleWorkflow;

    /**
     * Constructor.
     *
     * @param type \Cms\Article\Interfaces\ArticleRepositoryInterface $article
     *
     * @return type
     */
    public function __construct(ArticleRepositoryInterface $article)
    {
        $this->repository = $article;
        parent::__construct();
    }

    /**
     * Show article's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $articles = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('article::article.names'))
            ->view('article::public.article.index')
            ->data(compact('articles'))
            ->output();
    }


    /**
     * Show article.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $article = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($article->name . trans('article::article.name'))
            ->view('article::public.article.show')
            ->data(compact('article'))
            ->output();
    }

}
